{ config, lib, pkgs, ... }:

{
  boot.loader.initScript.enable = lib.mkForce false;

  c3d2.mergeNncpSettings = false;

  networking = {
    hostName = "nncp";
    firewall.enable = false;
  };

  programs.nncp = {
    enable = true;
    secrets = [ "/etc/nncp.secrets" ];
    settings = {
      mcd-listen = [ "eth0" ];
      mcd-send.eth0 = 60;
      neigh = # use c3d2.nncp.neigh but remove this node
        lib.mapAttrs
        (name: value: value // { via = lib.lists.remove "c3d2" value.via; })
        (builtins.removeAttrs config.c3d2.nncp.neigh [ "c3d2" ]);
    };
  };

  services.nncp = {
    caller.enable = false;
    daemon = {
      enable = true;
      socketActivation.enable = false;
    };
  };

  systemd.services."nncp-daemon-yggdrasil" = {
    after = [ "network.target" ];
    wantedBy = [ "multi-user.target" ];
    serviceConfig = config.systemd.services."nncp-daemon".serviceConfig // {
      ExecStart =
        "${pkgs.nncp}/bin/nncp-daemon -noprogress -autotoss -yggdrasil 'keyprv;;keypub;tcp://[2a00:8180:2c00:281:9000::1]:1337'";
    };
  };

}

